fnss.traffic.eventscheduling.write_event_schedule — FNSS 0.1.2 documentation

### Navigation

- index
- modules |
- modules |
- next |
- previous |
- FNSS 0.1.2 documentation »
- API Reference »
- Functions »

# fnss.traffic.eventscheduling.write_event_schedule

`write_event_schedule`(event_schedule, path, encoding='utf-8', prettyprint=True)

  Write an event schedule object to an XML file.

### Navigation

- index
- modules |
- modules |
- next |
- previous |
- FNSS 0.1.2 documentation »
- API Reference »
- Functions »